==========
Contact us
==========

If you need help, would like to ask a question about the tool, give us a feedback, or suggest a new feature you can now use `GitHub discussions <https://github.com/CenterForTheBuiltEnvironment/pythermalcomfort/discussions>`_.

Bug reports
===========

You can report bugs using `GitHub issues <https://github.com/CenterForTheBuiltEnvironment/pythermalcomfort/issues>`_.
When reporting a bug please include:

    * Your operating system name and version.
    * Any details about your local setup that might be helpful in troubleshooting.
    * Detailed steps to reproduce the bug.
